current_span_id

Function current_span_id 

pub fn current_span_id() -> Option<SpanId>
Get the span ID of the currently entered span on this thread, if any.

Returns None if no span is currently entered or the span ID is invalid.