pub struct MaxGaugeF64 { /* private fields */ }Expand description
A thread-sharded maximum tracker for floating-point values.
NaN observations are ignored.
Implementations
Sourceimpl MaxGaugeF64
impl MaxGaugeF64
Sourcepub fn new(shard_count: usize) -> Self
pub fn new(shard_count: usize) -> Self
Create a new max gauge with all shards initialized to zero.
Sourcepub fn with_value(shard_count: usize, initial: f64) -> Self
pub fn with_value(shard_count: usize, initial: f64) -> Self
Create a new max gauge with all shards initialized to initial.
Sourcepub fn swap_reset(&self) -> f64
pub fn swap_reset(&self) -> f64
Reset all shards and return the previous maximum.