pub struct LabeledGauge<L: LabelEnum> { /* private fields */ }Expand description
A gauge indexed by an enum label, providing O(1) dimensional metrics.
Each label variant has its own gauge for independent point-in-time values.
Example
ⓘ
use fast_telemetry::{LabeledGauge, LabelEnum};
#[derive(Copy, Clone, Debug)]
enum CacheType { Memory, Disk, Network }
impl LabelEnum for CacheType {
const CARDINALITY: usize = 3;
const LABEL_NAME: &'static str = "cache_type";
fn as_index(self) -> usize { self as usize }
fn from_index(index: usize) -> Self {
match index {
0 => Self::Memory, 1 => Self::Disk, _ => Self::Network,
}
}
fn variant_name(self) -> &'static str {
match self {
Self::Memory => "memory", Self::Disk => "disk", Self::Network => "network",
}
}
}
let gauge: LabeledGauge<CacheType> = LabeledGauge::new();
gauge.set(CacheType::Memory, 1024);
gauge.set(CacheType::Disk, 4096);
// Iteration for export
for (label, value) in gauge.iter() {
println!("{}={}: {}", CacheType::LABEL_NAME, label.variant_name(), value);
}Implementations
Sourceimpl<L: LabelEnum> LabeledGauge<L>
impl<L: LabelEnum> LabeledGauge<L>