pub struct LabeledSampledTimer<L: LabelEnum> { /* private fields */ }Expand description
Label-indexed sampled timer with O(1) lookup.
Implementations
Sourceimpl<L: LabelEnum> LabeledSampledTimer<L>
impl<L: LabelEnum> LabeledSampledTimer<L>
Sourcepub fn new(bounds_nanos: &[u64], shard_count: usize, sample_stride: u64) -> Self
pub fn new(bounds_nanos: &[u64], shard_count: usize, sample_stride: u64) -> Self
Create a labeled sampled timer with custom histogram bounds in nanoseconds.
Sourcepub fn with_latency_buckets(shard_count: usize, sample_stride: u64) -> Self
pub fn with_latency_buckets(shard_count: usize, sample_stride: u64) -> Self
Create a labeled sampled timer with default latency buckets in nanoseconds.
Sourcepub fn start(&self, label: L) -> SampledTimerGuard<'_>
pub fn start(&self, label: L) -> SampledTimerGuard<'_>
Start timing one labeled operation.
Sourcepub fn record_elapsed(&self, label: L, elapsed: Duration)
pub fn record_elapsed(&self, label: L, elapsed: Duration)
Record an already-measured duration for the given label if it should be sampled.
Sourcepub fn sample_count(&self, label: L) -> u64
pub fn sample_count(&self, label: L) -> u64
Number of latency samples recorded for a label.
Sourcepub fn sample_sum_nanos(&self, label: L) -> u64
pub fn sample_sum_nanos(&self, label: L) -> u64
Sum of sampled latency values in nanoseconds for a label.
Sourcepub fn avg_sample_nanos(&self, label: L) -> Option<f64>
pub fn avg_sample_nanos(&self, label: L) -> Option<f64>
Average sampled latency in nanoseconds for a label.
Sourcepub fn calls_metric(&self, label: L) -> &Counter
pub fn calls_metric(&self, label: L) -> &Counter
Access the underlying call counter for a label.